@@ -18,10 +18,14 @@ test_that("plot_linearEffects", {
   gg2 <- plot_linearEffects(model,
                             variables = c("residence_region", "household_size"))
   gg3 <- plot_linearEffects(model_logLink)
+  gg4 <- plot_linearEffects(model_logLink, refCat = TRUE)
+  gg5 <- plot_linearEffects(model, refCat= TRUE)
   
   expect_s3_class(gg1, class = c("gg","ggplot"))
   expect_s3_class(gg2, class = c("gg","ggplot"))
   expect_s3_class(gg3, class = c("gg", "ggplot"))
+  expect_s3_class(gg4, class = c("gg", "ggplot"))
+  expect_s3_class(gg5, class = c("gg", "ggplot"))
   
   # plot_linearEffects - return_plotData
   gg_dat1 <- plot_linearEffects(model, return_plotData = TRUE)
@@ -46,12 +50,15 @@ test_that("plot_1Dsmooth", {
   
   # plot_1Dsmooth
   gg1 <- plot_1Dsmooth(model, select = 2, alpha = 0.1)
-  expect_warning({
-    gg2 <- plot_1Dsmooth(model_logLink, select = 2, alpha = 0.1)
-  })
+  #expect_warning({
+    gg2 <- plot_1Dsmooth(model_logLink, select = 2, alpha = 0.5,
+                         method_expTransform = "delta")
+    gg3 <- plot_1Dsmooth(model_logLink, select = 2, alpha = 0.5)
+  #})
   
   expect_s3_class(gg1, class = c("gg","ggplot"))
   expect_s3_class(gg2, class = c("gg","ggplot"))
+  expect_s3_class(gg3, class = c("gg","ggplot"))
   
   expect_error(plot_1Dsmooth(model, select = 20))
   
